multidim.covertree.CoverTree.sparse_complex — GDA Toolbox v1.0 Manual

# multidim.covertree.CoverTree.sparse_complex

`CoverTree.` `sparse_complex`(level=-1)

  Make a sparse complex from this CoverTree, using the type-4 friends algorithm.

  Parameters: | level: int Level to use. (Default: -1, meaning len(self)
  Returns: | PointCloud object, with edge values coming from sparse complex algorithm.

  Notes

  This is a placeholder. Sparse Complexes are not currently implemented in the stable codebase.

#### Previous topic

multidim.covertree.CoverTree.reset

#### Next topic

multidim.SimplicialComplex